import sys, os
from tayto import linux

version = ''.join(sys.version.split('.')[:2])
home = os.getcwd()
path, mode, *_ = sys.argv[1:]
folder, filename, ext = linux.path_break(path)


if mode == 'exe':
  if ext == 'py':
    os.system(f'python3 {path}')
  elif ext == 'sh':
    os.system(f'chmod +x {path}')
    os.system(f'/usr/bin/bash {path}')
  elif ext == 'js':
    os.system(f'node {path}')

if mode == 'test': pass


'''
~/.config/Code/User/keybindings.json
{
  "key": "ctrl+shift+1",
  "command": "workbench.action.terminal.sendSequence",
  "args": {
    "text": "python3 /home/quang/Desktop/tayto/src/tayto/execute.py ${file} exe\u000D"
  }
},
'''


from tayto import linux


def pushcode(src:str, dst:str, base:str, new:str) -> None:
  from uuid import uuid4
  folder = f'/tmp/{uuid4()}'
  linux.bash(f'''
rm -rf {folder}
mkdir -p {folder}/code
cd {folder}
ln -s {src} code
cat > Dockerfile << EOF
FROM {base}
ADD code {dst}
EOF
docker image rm -f {new}
docker build -t {new} .
cd ~
''')

